#!/usr/bin/env python
# -*- coding: utf-8 -*-

# # Chicago
# 
# This notebooks displays some of the data available at [Business Licenses - Current Active](https://data.cityofchicago.org/Community-Economic-Development/Business-Licenses-Current-Active/uupf-x98q). We assume the data was downloaded.

# In[1]:


from jyquickhelper import add_notebook_menu
add_notebook_menu()


# In[2]:


get_ipython().run_line_magic('matplotlib', 'inline')


# ## Data

# In[3]:


from pyensae.datasource import download_data
file = download_data("rows.csv", url="https://data.cityofchicago.org/api/views/uupf-x98q/")


# ## Businesses

# In[4]:


import pandas
businesses = df = pandas.read_csv("rows.csv", low_memory=False)
df.head()


# In[5]:


df.plot(x="LONGITUDE", y="LATITUDE", kind="scatter");


# In[6]:


minlon, maxlon = df["LONGITUDE"].min(), df["LONGITUDE"].max()
minlat, maxlat = df["LATITUDE"].min(), df["LATITUDE"].max()
minlon, maxlon, minlat, maxlat


# In[7]:


import cartopy.crs as ccrs
import cartopy.feature as cfeature
import matplotlib.pyplot as plt

fig = plt.figure(figsize=(7, 7))
ax = fig.add_subplot(1, 1, 1, projection=ccrs.PlateCarree())
ax.set_extent([minlon, maxlon, minlat, maxlat])
ax.add_feature(cfeature.OCEAN)
ax.add_feature(cfeature.COASTLINE)
ax.add_feature(cfeature.LAKES)
ax.add_feature(cfeature.LAND)
ax.add_feature(cfeature.RIVERS)
ax.add_feature(cfeature.BORDERS, linestyle=':')

ax.plot(df["LONGITUDE"], df["LATITUDE"], '.', ms=0.9);


# In[8]: